/*	The three textures contain the positions, normals and albedo 
	(=color) informations for every pixel that is rendered.
*/
uniform sampler2D position;
uniform sampler2D normal;
uniform sampler2D albedo;

void main()
{
	/*	We set a single light source. You could make this uniform and
		therefore changable, but for our purpose, this is okay. Because
		We calculate the lighting during the fragment pass, the cost of
		lighting is independent of scene complexity :) This is one of
		the benefits of using deferred shading.
	*/
	const vec3 lightPos = vec3( 20.0, 10.0, 14.0 );

	/* Simple phong shading. Feel free to replace this with something more
		fancy.
	*/
	vec3 N = normalize(texture2D(normal, gl_TexCoord[0].st).xyz);
	vec3 L = normalize(lightPos - texture2D(position, gl_TexCoord[0].st).xyz);
	
	float shade = max( dot(N, L), 0.0);
	vec3 color = texture2D(albedo, gl_TexCoord[0].st).rgb;	
	color *= shade;

	gl_FragColor = vec4( color, 1.0 );
}

